DnsRequest

Struct DnsRequest 

pub struct DnsRequest { /* private fields */ }
A DNS request object

This wraps a DNS Message for requests. It also has request options associated for controlling certain features of the DNS protocol handlers.

Implementations

Source

impl DnsRequest

pub fn from_query(query: Query, options: DnsRequestOptions) -> Self

Build a new DnsRequest from a Query and DnsRequestOptions.

pub fn new(message: Message, options: DnsRequestOptions) -> Self

Returns a new DnsRequest object

pub fn with_original_query(self, original_query: Option<Query>) -> Self

Add the original query

pub fn options(&self) -> &DnsRequestOptions

Get the set of request options associated with this request

pub fn options_mut(&mut self) -> &mut DnsRequestOptions

Get a mutable reference to the request options associated with this request

pub fn into_parts(self) -> (Message, DnsRequestOptions)

Unwraps the raw message

pub fn original_query(&self) -> Option<&Query>

Get the request’s original query

Methods from Deref<Target = Message>

pub fn truncate(&self) -> Self

Truncates a Message, this blindly removes all response fields and sets truncated to true

pub fn add_query(&mut self, query: Query) -> &mut Self

Add a query to the Message, either the query response from the server, or the request Query.

pub fn add_queries<Q, I>(&mut self, queries: Q) -> &mut Self
where Q: IntoIterator<Item = Query, IntoIter = I>, I: Iterator<Item = Query>,

Adds an iterator over a set of Queries to be added to the message

pub fn add_answer(&mut self, record: Record) -> &mut Self

Add a record to the Answer section.

pub fn add_answers<R, I>(&mut self, records: R) -> &mut Self
where R: IntoIterator<Item = Record, IntoIter = I>, I: Iterator<Item = Record>,

Add all the records from the iterator to the Answer section of the message.

pub fn insert_answers(&mut self, records: Vec<Record>)

Sets the Answer section to the specified set of records.

Panics

Will panic if the Answer section is already non-empty.

pub fn add_authority(&mut self, record: Record) -> &mut Self

Add a record to the Authority section.

pub fn add_authorities<R, I>(&mut self, records: R) -> &mut Self
where R: IntoIterator<Item = Record, IntoIter = I>, I: Iterator<Item = Record>,

Add all the records from the Iterator to the Authority section of the message.

pub fn insert_authorities(&mut self, records: Vec<Record>)

Sets the Authority section to the specified set of records.

Panics

Will panic if the Authority section is already non-empty.

pub fn add_additional(&mut self, record: Record) -> &mut Self

Add a record to the Additional section.

pub fn add_additionals<R, I>(&mut self, records: R) -> &mut Self
where R: IntoIterator<Item = Record, IntoIter = I>, I: Iterator<Item = Record>,

Add all the records from the iterator to the Additional section of the message.

pub fn insert_additionals(&mut self, records: Vec<Record>)

Sets the Additional to the specified set of records.

Panics

Will panic if additional records are already associated to the message.

pub fn set_edns(&mut self, edns: Edns) -> &mut Self

Add the EDNS OPT pseudo-RR to the Message

pub fn take_all_sections(&mut self) -> impl Iterator<Item = Record>

Consume the message, returning an iterator over records from all sections

pub fn all_sections(&self) -> impl Iterator<Item = &Record>

All sections chained

pub fn max_payload(&self) -> u16

Return value

the max payload value as it’s defined in the EDNS OPT pseudo-RR.

pub fn version(&self) -> u8

Return value

the version as defined in the EDNS record

pub fn signature(&self) -> Option<&Record<TSIG>>

Return value

the signature over the message, if any

pub fn take_signature(&mut self) -> Option<Box<Record<TSIG>>>

Remove signatures from the Message

pub fn to_vec(&self) -> Result<Vec<u8>, ProtoError>

Encodes the Message into a buffer

Methods from Deref<Target = Metadata>

pub fn flags(&self) -> Flags

A method to get all header flags (useful for Display purposes)