DnsRequestOptions

Struct DnsRequestOptions 

#[non_exhaustive]
pub struct DnsRequestOptions { pub use_edns: bool, pub edns_payload_len: u16, pub edns_set_dnssec_ok: bool, pub max_request_depth: usize, pub recursion_desired: bool, pub case_randomization: bool, pub retry_interval: Duration, }
A set of options for expressing options to how requests should be treated

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
use_edns: bool

When true, will add EDNS options to the request.

edns_payload_len: u16

EDNS UDP payload size.

Sets the requestor’s UDP payload size in the EDNS(0) OPT pseudo-RR in outgoing requests. This tells other servers when they need to truncate their responses. Smaller payload sizes require more queries with large responses to be retried over TCP, while larger payload sizes lead to large responses being fragmented or dropped if they exceed the MTU of a network.

See https://www.dnsflagday.net/2020/ and RFC 9715 for discussion.

edns_set_dnssec_ok: bool

When true, sets the DO bit in the EDNS options

max_request_depth: usize

Specifies maximum request depth for DNSSEC validation.

recursion_desired: bool

set recursion desired (or not) for any requests

case_randomization: bool

Randomize case of query name, and check that the response matches, for spoofing resistance.

retry_interval: Duration

Retry interval for unreliable transport protocols (plain UDP). Any value lower than the retry_interval_floor value set by a protocol implementer will effectively be ignored, but higher values will result in less frequent retries.