IntoName

Trait IntoName 

pub trait IntoName: Sized {
    // Required methods
    fn into_name(self) -> Result<Name, ProtoError>;
    fn to_ip(&self) -> Option<IpAddr>;
}
Conversion into a Name

Required Methods

fn into_name(self) -> Result<Name, ProtoError>

Convert this into Name

fn to_ip(&self) -> Option<IpAddr>

Check if this value is a valid IP address

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoName for &String

Source

fn into_name(self) -> Result<Name, ProtoError>

Performs a utf8, IDNA or punycode, translation of the &String into Name

Source

fn to_ip(&self) -> Option<IpAddr>

Source

impl IntoName for &str

Source

fn into_name(self) -> Result<Name, ProtoError>

Performs a utf8, IDNA or punycode, translation of the str into Name

Source

fn to_ip(&self) -> Option<IpAddr>

Source

impl IntoName for String

Source

fn into_name(self) -> Result<Name, ProtoError>

Performs a utf8, IDNA or punycode, translation of the String into Name

Source

fn to_ip(&self) -> Option<IpAddr>

Implementors

Source

impl<T> IntoName for T
where T: Into<Name>,