pub struct HTTPS(pub SVCB);Expand description
HTTPS is really a derivation of the original SVCB record data. See SVCB for more documentation
Tuple Fields
0: SVCBTrait Implementations
Sourceimpl BinEncodable for HTTPS
impl BinEncodable for HTTPS
Sourcefn emit(&self, encoder: &mut BinEncoder<'_>) -> Result<(), ProtoError>
fn emit(&self, encoder: &mut BinEncoder<'_>) -> Result<(), ProtoError>
Write the type to the stream
Sourceimpl<'de> Deserialize<'de> for HTTPS
impl<'de> Deserialize<'de> for HTTPS
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for HTTPS
Sourceimpl RecordData for HTTPS
impl RecordData for HTTPS
Sourcefn try_borrow(data: &RData) -> Option<&Self>
fn try_borrow(data: &RData) -> Option<&Self>
Attempts to borrow this RecordData from the RData type, if it is not the correct type the original is returned
Sourcefn record_type(&self) -> RecordType
fn record_type(&self) -> RecordType
Get the associated RecordType for the RecordData
Sourcefn into_rdata(self) -> RData
fn into_rdata(self) -> RData
Converts this RecordData into generic RecordData
impl StructuralPartialEq for HTTPS