#[non_exhaustive]pub struct OPENPGPKEY {
pub public_key: Vec<u8>,
}Expand description
The RDATA portion of an OPENPGPKEY resource record contains a single
value consisting of a Transferable Public Key formatted as specified
in [RFC4880].Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.public_key: Vec<u8>The public key.
This should be an OpenPGP Transferable Public Key, but this is not guaranteed.
Implementations