SMIMEA

Struct SMIMEA 

pub struct SMIMEA(pub TLSA);
RFC 8162

The SMIMEA wire format and presentation format are the same as for the TLSA record

Tuple Fields

0: TLSA

Implementations

Source

impl SMIMEA

pub fn new( cert_usage: CertUsage, selector: Selector, matching: Matching, cert_data: Vec<u8>, ) -> Self

Construct a new SMIMEA

RFC 8162

2.  The SMIMEA Resource Record

   The SMIMEA DNS resource record (RR) is used to associate an end
   entity certificate or public key with the associated email address,
   thus forming a "SMIMEA certificate association".  The semantics of
   how the SMIMEA resource record is interpreted are given later in this
   document.  Note that the information returned in the SMIMEA record
   might be for the end entity certificate, or it might be for the trust
   anchor or an intermediate certificate.  This mechanism is similar to
   the one given in [RFC7929] for OpenPGP.

   The type value for the SMIMEA RRtype is defined in Section 8.  The
   SMIMEA resource record is class independent.