pub enum SvcParamValue {
Mandatory(Mandatory),
Alpn(Alpn),
NoDefaultAlpn,
Port(u16),
Ipv4Hint(IpHint<A>),
EchConfigList(EchConfigList),
Ipv6Hint(IpHint<AAAA>),
Unknown(Unknown),
}Expand description
Warning, it is currently up to users of this type to validate the data against that expected by the key
* a 2 octet field containing the length of the SvcParamValue as an
integer between 0 and 65535 in network byte order (but constrained
by the RDATA and DNS message sizes).
* an octet string of this length whose contents are in a format
determined by the SvcParamKey.Variants
Mandatory(Mandatory)
In a ServiceMode RR, a SvcParamKey is considered “mandatory” if the RR will not function correctly for clients that ignore this SvcParamKey. Each SVCB protocol mapping SHOULD specify a set of keys that are “automatically mandatory”, i.e. mandatory if they are present in an RR. The SvcParamKey “mandatory” is used to indicate any mandatory keys for this RR, in addition to any automatically mandatory keys that are present.
see Mandatory
Alpn(Alpn)
RFC 9460 SVCB and HTTPS Resource Records, Nov 2023
The "alpn" and "no-default-alpn" SvcParamKeys together indicate the
set of Application Layer Protocol Negotiation (ALPN) protocol
identifiers [Alpn] and associated transport protocols supported by
this service endpoint (the "SVCB ALPN set").NoDefaultAlpn
For “no-default-alpn”, the presentation and wire format values MUST
be empty.
See also Alpn
Port(u16)
RFC 9460 SVCB and HTTPS Resource Records, Nov 2023
7.2. "port"
The "port" SvcParamKey defines the TCP or UDP port that should be
used to reach this alternative endpoint. If this key is not present,
clients SHALL use the authority endpoint's port number.
The presentation value of the SvcParamValue is a single decimal
integer between 0 and 65535 in ASCII. Any other value (e.g. an
empty value) is a syntax error. To enable simpler parsing, this
SvcParam MUST NOT contain escape sequences.
The wire format of the SvcParamValue is the corresponding 2 octet
numeric value in network byte order.
If a port-restricting firewall is in place between some client and
the service endpoint, changing the port number might cause that
client to lose access to the service, so operators should exercise
caution when using this SvcParamKey to specify a non-default port.Ipv4Hint(IpHint<A>)
RFC 9460 SVCB and HTTPS Resource Records, Nov 2023
The “ipv4hint” and “ipv6hint” keys convey IP addresses that clients MAY use to reach the service. If A and AAAA records for TargetName are locally available, the client SHOULD ignore these hints. Otherwise, clients SHOULD perform A and/or AAAA queries for TargetName as in Section 3, and clients SHOULD use the IP address in those responses for future connections. Clients MAY opt to terminate any connections using the addresses in hints and instead switch to the addresses in response to the TargetName query. Failure to use A and/or AAAA response addresses could negatively impact load balancing or other geo-aware features and thereby degrade client performance.
see IpHint
EchConfigList(EchConfigList)
2. "SvcParam for ECH configuration"
The "ech" SvcParamKey is defined for conveying the ECH configuration
of an alternative endpoint. It is applicable to all TLS-based protocols
(including DTLS [RFC9147] and QUIC version 1 [RFC9001]) unless otherwise
specified.Ipv6Hint(IpHint<AAAA>)
See IpHint
Unknown(Unknown)
Unparsed network data. Refer to documents on the associated key value
This will be left as is when read off the wire, and encoded in bas64 for presentation.