Matching

Enum Matching 

pub enum Matching {
    Raw,
    Sha256,
    Sha512,
    Unassigned(u8),
    Private,
}
RFC 6698, DNS-Based Authentication for TLS

2.1.3.  The Matching Type Field

   A one-octet value, called "matching type", specifies how the
   certificate association is presented.  This value is defined in a new
   IANA registry (see Section 7.4).  The types defined in this document
   are:

      0 -- Raw

      1 -- Sha256

      2 -- Sha512

   If the TLSA record's matching type is a hash, having the record use
   the same hash algorithm that was used in the signature in the
   certificate (if possible) will assist clients that support a small
   number of hash algorithms.

Variants



Raw

Exact match on selected content



Sha256

SHA-256 hash of selected content RFC6234



Sha512

SHA-512 hash of selected content RFC6234



Unassigned(u8)

Unassigned at the time of this writing



Private

Private usage