pub struct RrKey {
pub name: LowerName,
pub record_type: RecordType,
}Expand description
Accessor key for RRSets in the Authority.
Fields
name: LowerNameMatches the name in the Record of this key
record_type: RecordTypeMatches the type of the Record of this key
Implementations