pub struct TSigner(/* private fields */);Expand description
Struct to pass to a client for it to authenticate requests using TSIG.
Implementations
Sourceimpl TSigner
impl TSigner
Sourcepub fn algorithm(&self) -> &TsigAlgorithm
pub fn algorithm(&self) -> &TsigAlgorithm
Return the algorithm used for message authentication
Sourcepub fn signer_name(&self) -> &Name
pub fn signer_name(&self) -> &Name
Name of the key used by this signer
Sourcepub fn fudge(&self) -> u16
pub fn fudge(&self) -> u16
Maximum time difference between client time when issuing a message, and server time when receiving it, in second. If time is out, the server will consider the request invalid. Longer values means more room for replay by an attacker. A few minutes are usually a good value.
Sourcepub fn should_sign_message(&self, message: &Message) -> bool
pub fn should_sign_message(&self, message: &Message) -> bool
Returns true if the TSigner should sign the given Message