pub struct Place<T: EncodedSize> { /* private fields */ }Expand description
A place in the encoded stream that the encoder can rewrite
Implementations
Sourceimpl<T: EncodedSize> Place<T>
impl<T: EncodedSize> Place<T>
Sourcepub fn replace(
self,
encoder: &mut BinEncoder<'_>,
data: T,
) -> Result<(), ProtoError>
pub fn replace( self, encoder: &mut BinEncoder<'_>, data: T, ) -> Result<(), ProtoError>
Replaces the data at this place with the given data