#[non_exhaustive]pub enum LexerError {
EOF,
IllegalCharacter(char),
IllegalState(&'static str),
Message(&'static str),
UnclosedList,
UnclosedQuotedString,
UnrecognizedChar(char),
UnrecognizedDollar(String),
UnrecognizedOctet(u32),
}Expand description
The error kind for lexer errors that get returned in the crate
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EOF
Unexpected end of input
IllegalCharacter(char)
An illegal character was found
IllegalState(&'static str)
An illegal state was reached
Message(&'static str)
An error with an arbitrary message, referenced as &’static str
UnclosedList
An unclosed list was found
UnclosedQuotedString
An unclosed quoted string was found
UnrecognizedChar(char)
An unrecognized character was found
UnrecognizedDollar(String)
An unrecognized dollar content was found
UnrecognizedOctet(u32)
An unrecognized octet was found