pub struct AccessControlSet { /* private fields */ }access-control only.Expand description
An IPv4/IPv6 access control set.
Use AccessControlSetBuilder to construct an instance.
When determining if an IpAddr is denied with Self::denied(), the deny list
is considered first, and the allow list may override the deny
decision.
The full access semantics are:
| Present in deny list | Present in allow list | Result |
|---|---|---|
| true | false | denied |
| false | false | allowed |
| true | true | allowed |
| false | true | allowed |
Implementations
Sourceimpl AccessControlSet
impl AccessControlSet
Sourcepub fn empty(name: &'static str) -> Self
pub fn empty(name: &'static str) -> Self
Construct an empty access control set with the given name that allows all networks.
Sourcepub fn allows_all(&self) -> bool
pub fn allows_all(&self) -> bool
Returns true if the access control set allows all addresses.
This is true when no IPv4 or IPv6 networks are denied.
Sourcepub fn denied(&self, ip: IpAddr) -> bool
pub fn denied(&self, ip: IpAddr) -> bool
Check if the IP address ip should be denied.
If the IP address is in a network previously denied by AccessControlSetBuilder::deny()
that wasn’t explicitly allowed with AccessControlSetBuilder::allow(), this function
will return true.
All other combinations will return false (i.e., AccessControlSetBuilder::allow() acts
like an exception list for AccessControlSetBuilder::deny())