#[non_exhaustive]pub enum ProtoError {
Show 13 variants
#[non_exhaustive] CharacterDataTooLong {
max: usize,
len: usize,
},
Crypto(&'static str),
Decode(DecodeError),
FormError {
header: Metadata,
error: Box<Self>,
},
MaxBufferSizeExceeded(usize),
Message(&'static str),
Msg(String),
#[non_exhaustive] NotAllRecordsWritten {
count: usize,
},
NotAResponse,
UrlParsing(ParseError),
Utf8(Utf8Error),
FromUtf8(FromUtf8Error),
ParseInt(ParseIntError),
}Expand description
The error kind for errors that get returned in the crate
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
#[non_exhaustive]CharacterDataTooLong
Character data length exceeded the limit
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
Crypto(&'static str)
Available on crate feature
__dnssec only.Crypto operation failed
Decode(DecodeError)
Message decoding error
FormError
Format error in Message Parsing
Fields
MaxBufferSizeExceeded(usize)
The maximum buffer size was exceeded
Message(&'static str)
An error with an arbitrary message, referenced as &’static str
Msg(String)
An error with an arbitrary message, stored as String
#[non_exhaustive]NotAllRecordsWritten
Not all records were able to be written
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
NotAResponse
A response was received with QR=0, indicating it was a query and not a response
UrlParsing(ParseError)
An url parsing error
Utf8(Utf8Error)
A utf8 parsing error
FromUtf8(FromUtf8Error)
A utf8 parsing error
ParseInt(ParseIntError)
An int parsing error