pub struct SMIMEA(pub TLSA);Expand description
Tuple Fields
0: TLSAImplementations
Sourceimpl SMIMEA
impl SMIMEA
Sourcepub fn new(
cert_usage: CertUsage,
selector: Selector,
matching: Matching,
cert_data: Vec<u8>,
) -> Self
pub fn new( cert_usage: CertUsage, selector: Selector, matching: Matching, cert_data: Vec<u8>, ) -> Self
Construct a new SMIMEA
2. The SMIMEA Resource Record
The SMIMEA DNS resource record (RR) is used to associate an end
entity certificate or public key with the associated email address,
thus forming a "SMIMEA certificate association". The semantics of
how the SMIMEA resource record is interpreted are given later in this
document. Note that the information returned in the SMIMEA record
might be for the end entity certificate, or it might be for the trust
anchor or an intermediate certificate. This mechanism is similar to
the one given in [RFC7929] for OpenPGP.
The type value for the SMIMEA RRtype is defined in Section 8. The
SMIMEA resource record is class independent.Trait Implementations
Sourceimpl BinEncodable for SMIMEA
impl BinEncodable for SMIMEA
Sourcefn emit(&self, encoder: &mut BinEncoder<'_>) -> Result<(), ProtoError>
fn emit(&self, encoder: &mut BinEncoder<'_>) -> Result<(), ProtoError>
Write the type to the stream
Sourceimpl RecordData for SMIMEA
impl RecordData for SMIMEA
Sourcefn try_borrow(data: &RData) -> Option<&Self>
fn try_borrow(data: &RData) -> Option<&Self>
Attempts to borrow this RecordData from the RData type, if it is not the correct type the original is returned
Sourcefn record_type(&self) -> RecordType
fn record_type(&self) -> RecordType
Get the associated RecordType for the RecordData
Sourcefn into_rdata(self) -> RData
fn into_rdata(self) -> RData
Converts this RecordData into generic RecordData
impl Eq for SMIMEA
impl StructuralPartialEq for SMIMEA