pub enum RDataEncoding {
StandardRecord,
Canonical,
Other,
}Expand description
Determines how names inside RDATA are encoded, depending on the record type and whether DNSSEC canonical form is used.
Variants
StandardRecord
Applicable to standard record types defined in RFC 1035 section 3.3.
Names in the RDATA may be compressed, since these record types are well-known. When encoding in DNSSEC canonical form, compression is not used, and names are transformed to lowercase. Note that all standard types that contain names in the RDATA are also on the list in RFC 4034 section 6.2.
Canonical
Applicable to record types that were defined after RFC 1035, for which the DNSSEC canonical form of the RDATA has names transformed to lowercase. Compression is never used.
This applies to the list of record types defined in RFC 4034 section 6.2 and modified by RFC 6840, section 5.1.
Other
Applicable to record types for which names in the RDATA are never compressed and never transformed to lowercase.
All newly defined record types must have this behavior, per RFC 3597 section 4 and section 7.